@@ -1,4 +1,4 @@
-"Xarchie.archieHost:	archie.mcgill.ca",
+"Xarchie.archieHost:	archie.sura.net",
 "Xarchie.searchType:	exact",
 "Xarchie.sortType:	default",
 "Xarchie.maxHits:	99",
@@ -8,20 +8,21 @@
 "Xarchie.niceLevel:	0",
 "Xarchie.ftpDir:		.",
 "Xarchie.ftpMode:	binary",
+"Xarchie.saveFormatOneLine:	False",
 "Xarchie.debugLevel:	0",
+"Xarchie.expert:		False",
 "Xarchie.widgets: \
 	toplevel			Paned		outerPaned \
 \
 	outerPaned			Form		buttonForm \
 	outerPaned.buttonForm		Command		quitButton \
 	outerPaned.buttonForm		Command		queryButton \
+	outerPaned.buttonForm		Command		abortButton \
+	outerPaned.buttonForm		Command		saveButton \
 	outerPaned.buttonForm		Command		ftpButton \
 	outerPaned.buttonForm		MenuButton	searchButton \
-	outerPaned.buttonForm.searchButton EzMenu	searchNowMenu \
 	outerPaned.buttonForm		MenuButton	sortButton \
-	outerPaned.buttonForm.sortButton EzMenu		sortNowMenu \
 	outerPaned.buttonForm		MenuButton	niceButton \
-	outerPaned.buttonForm.niceButton EzMenu		niceNowMenu \
 	outerPaned.buttonForm		Command		settingsButton \
 	outerPaned.buttonForm		Label		statusLabel \
 	outerPaned.buttonForm		AsciiText	statusText \
@@ -49,6 +50,10 @@
 	outerPaned.stringForm	AsciiText		modesText \
 	outerPaned.stringForm	Label			dateLabel \
 	outerPaned.stringForm	AsciiText		dateText ",
+"Xarchie.menus:\
+	outerPaned.buttonForm.searchButton EzMenu	searchNowMenu \
+	outerPaned.buttonForm.sortButton EzMenu		sortNowMenu \
+	outerPaned.buttonForm.niceButton EzMenu		niceNowMenu",
 "Xarchie.settingsWidgets:\
 	toplevel			TopLevelShell	settingsShell \
 	settingsShell			Form		settingsForm \
@@ -64,7 +69,7 @@
 	settingsShell.settingsForm	Label		sortLabel \
 	settingsShell.settingsForm	MenuButton	hostButton \
 	settingsShell.settingsForm	EzMenu		hostMenu \
-	settingsShell.settingsForm	AsciiText	hostText \
+	settingsShell.settingsForm	AsciiText	setHostText \
 	settingsShell.settingsForm	Label		maxHitsLabel \
 	settingsShell.settingsForm	AsciiText	maxHitsText \
 	settingsShell.settingsForm	Label		timeoutLabel \
@@ -105,15 +110,28 @@
 	<Enter>:	display-caret(True) \\n\
 	<Leave>:	display-caret(False) \\n",
 "Xarchie*outerPaned.orientation:	vertical",
+"Xarchie*buttonForm.min: 50",
+"Xarchie*buttonForm.max: 50",
+"Xarchie*buttonForm.showGrip: False",
 "Xarchie*buttonForm*quitButton.label:	Quit",
 "Xarchie*buttonForm*quitButton.translations:#override\\n\
-	<Btn1Down>,<Btn1Up>:	quit() \\n",
+	Shift<Btn1Down>,<Btn1Up>:	quit(always) \\n\
+	<Btn1Down>,<Btn1Up>:		quit() \\n",
 "Xarchie*buttonForm*queryButton.label:		Query",
 "Xarchie*buttonForm*queryButton.fromHoriz:	quitButton",
 "Xarchie*buttonForm*queryButton.translations:#override\\n\
 	<Btn1Down>,<Btn1Up>:	query() \\n",
+"Xarchie*buttonForm*abortButton.label:		Abort",
+"Xarchie*buttonForm*abortButton.fromHoriz:	queryButton",
+"Xarchie*buttonForm*abortButton.translations:#override\\n\
+	<Btn1Down>,<Btn1Up>:	abort() \\n",
+"Xarchie*buttonForm*saveButton.label:		Save",
+"Xarchie*buttonForm*saveButton.fromHoriz:	abortButton",
+"Xarchie*buttonForm*saveButton.translations:#override\\n\
+	Shift<Btn1Down>,<Btn1Up>:	save-to-file(\"%s.lst\") \\n\
+	<Btn1Down>,<Btn1Up>:		save-to-file() \\n",
 "Xarchie*buttonForm*ftpButton.label:		Ftp",
-"Xarchie*buttonForm*ftpButton.fromHoriz:		queryButton",
+"Xarchie*buttonForm*ftpButton.fromHoriz:		saveButton",
 "Xarchie*buttonForm*ftpButton.translations:#override\\n\
 	<Btn1Down>,<Btn1Up>:	ftp() \\n",
 "Xarchie*buttonForm*searchButton.label:		Search Type",
@@ -136,13 +154,20 @@
 "Xarchie*buttonForm*statusText*width:		410",
 "Xarchie*buttonForm*statusText*editType:		read",
 "Xarchie*buttonForm*statusText.borderWidth:	0",
+"Xarchie*buttonForm*statusText*scrollHorizontal:	never",
 "Xarchie*buttonForm*statusText*translations:#override\\n",
 "Xarchie*innerPaned.orientation:	horizontal",
+"Xarchie*innerPaned.showGrip: False",
 "Xarchie*stringForm.min: 120",
 "Xarchie*stringForm.max: 120",
+"Xarchie*stringForm*Label.justify:	left",
+"Xarchie*stringForm*Label.font:		fixed",
+"Xarchie*stringForm*AsciiSrc.editType: 	read",
 "Xarchie*stringForm*searchLabel.label:		Search Term:",
+"Xarchie*stringForm*searchLabel.font:		*fixed*bold*",
 "Xarchie*stringForm*searchText*width:		375",
 "Xarchie*stringForm*searchText.fromHoriz:	searchLabel",
+"Xarchie*stringForm*searchText*editType: 	edit",
 "Xarchie*stringForm*searchText*translations:#override\\n\
 	<Enter>:	display-caret(True) \\n\
 	<Leave>:	display-caret(False) \\n\
@@ -151,22 +176,22 @@
 "Xarchie*stringForm*hostLabel.fromVert:	searchLabel",
 "Xarchie*stringForm*hostText.fromVert:	searchLabel",
 "Xarchie*stringForm*hostText.fromHoriz:	hostLabel",
-"Xarchie*stringForm*hostText.width:	424",
+"Xarchie*stringForm*hostText.width:	429",
 "Xarchie*stringForm*locationLabel.label:		Location:",
 "Xarchie*stringForm*locationLabel.fromVert:	hostLabel",
 "Xarchie*stringForm*locationText.fromHoriz:	locationLabel",
 "Xarchie*stringForm*locationText.fromVert:	hostLabel",
-"Xarchie*stringForm*locationText.width:		396",
+"Xarchie*stringForm*locationText.width:		405",
 "Xarchie*stringForm*fileLabel.label:	File:",
 "Xarchie*stringForm*fileLabel.fromVert:	locationLabel",
 "Xarchie*stringForm*fileText.fromHoriz:	fileLabel",
 "Xarchie*stringForm*fileText.fromVert:	locationLabel",
-"Xarchie*stringForm*fileText.width:	424",
+"Xarchie*stringForm*fileText.width:	429",
 "Xarchie*stringForm*sizeLabel.label:	Size:",
 "Xarchie*stringForm*sizeLabel.fromVert:	fileLabel",
 "Xarchie*stringForm*sizeText.fromHoriz:	sizeLabel",
 "Xarchie*stringForm*sizeText.fromVert:	fileLabel",
-"Xarchie*stringForm*sizeText*width:	111",
+"Xarchie*stringForm*sizeText*width:	112",
 "Xarchie*stringForm*modesLabel.label:	Mode:",
 "Xarchie*stringForm*modesLabel.fromHoriz:sizeText",
 "Xarchie*stringForm*modesLabel.fromVert:	fileLabel",
@@ -178,7 +203,7 @@
 "Xarchie*stringForm*dateLabel.fromVert:	fileLabel",
 "Xarchie*stringForm*dateText.fromHoriz:	dateLabel",
 "Xarchie*stringForm*dateText.fromVert:	fileLabel",
-"Xarchie*stringForm*dateText*width:	111",
+"Xarchie*stringForm*dateText*width:	125",
 "Xarchie*settingsForm*Text*borderWidth:		0",
 "Xarchie*settingsForm*Label*resizable:		True",
 "Xarchie*settingsShell.title:			Xarchie Settings Panel",
@@ -210,9 +235,9 @@
 "Xarchie*settingsForm*hostButton.label:		Host:",
 "Xarchie*settingsForm*hostButton.menuName:	hostMenu",
 "Xarchie*settingsForm*hostButton.fromVert:	setSortButton",
-"Xarchie*settingsForm*hostText.fromVert:		setSortButton",
-"Xarchie*settingsForm*hostText.fromHoriz:	hostButton",
-"Xarchie*settingsForm*hostText*width:		200",
+"Xarchie*settingsForm*setHostText.fromVert:	setSortButton",
+"Xarchie*settingsForm*setHostText.fromHoriz:	hostButton",
+"Xarchie*settingsForm*setHostText*width:		200",
 "Xarchie*settingsForm*maxHitsLabel.label:	Max Hits:",
 "Xarchie*settingsForm*maxHitsLabel.fromVert:	hostButton",
 "Xarchie*settingsForm*maxHitsText.fromVert:	hostButton",
@@ -256,9 +281,12 @@
 "Xarchie*hostMenu.label:		Archie Hosts",
 "Xarchie*hostMenu.menu:\
    (line) \
+   (item \"archie.sura.net\"	(action \"set-host(archie.sura.net)\")) \
    (item \"archie.mcgill.ca\"	(action \"set-host(archie.mcgill.ca)\")) \
    (item \"archie.funet.fi\"	(action \"set-host(archie.funet.fi)\")) \
-   (item \"archie.au\"		(action \"set-host(archie.au)\"))",
+   (item \"archie.au\"		(action \"set-host(archie.au)\")) \
+   (item \"archie.doc.ic.ac.uk\"	(action \"set-host(archie.doc.ic.ac.uk)\")) \
+   (item \"cs.huji.ac.il\"	(action \"set-host(cs.huji.ac.il)\"))",
 "Xarchie*niceMenu.label:		Nice Levels",
 "Xarchie*niceMenu.menu:\
 	(line) \
@@ -294,7 +322,14 @@
 	(item \"Nicest\"		(action \"set-nice-level-now(32765)\"))",
 "Xarchie*allowShellResize:		True",
 "Xarchie*Dialog*Label.resizable:		True",
+"Xarchie*Dialog*Text*scrollHorizontal:	never",
 "Xarchie*Dialog.icon:			xlogo32",
 "Xarchie*alertDialog*okButton.label:	Ok",
 "Xarchie*confirmDialog*yesButton.label:	Yes",
 "Xarchie*confirmDialog*noButton.label:	No",
+"Xarchie*dialogDialog*okButton.label:	Ok",
+"Xarchie*dialogDialog*cancelButton.label:Cancel",
+"Xarchie*dialogDialog.value*translations:#override\\n\
+	<Key>Return:	dialog-ok() \\n\
+	<Enter>:	display-caret(True) \\n\
+	<Leave>:	display-caret(False) \\n",
