@@ -10,7 +10,7 @@
  * Finally, it provides the generic setText(), setLabel(), and status*()
  * routines which could go just about anywhere.
  *
- * George Ferguson, ferguson@cs.rochester.edu, 12 Sep 1991.
+ * George Ferguson, ferguson@cs.rochester.edu, 12 Nov 1991.
  *
  */
 #include <stdio.h>
@@ -33,6 +33,7 @@
 #include "classnames.h"
 #include "db.h"
 #include "actions.h"
+#include "settings.h"
 #include "patchlevel.h"
 
 /*	-	-	-	-	-	-	-	-	*/
@@ -40,7 +41,6 @@
  * Functions defined in this file:
  */
 int main();
-void doPendingEvents();
 void initWidgetsFromString();
 void displayHostInfo(), clearHostInfo();
 void displayLocationInfo(), clearLocationInfo();
@@ -49,7 +49,7 @@ void setText(), setLabel();
 void status0(), status1(), status2();
 void fail0(), fail1();
 
-static void initGraphics(), initWidgets();
+static void initGraphics(), initWidgets(), initErrorHandlers();
 static void selectItem();
 static void syntax();
 
@@ -67,6 +67,7 @@ XtAppContext appContext;
 Widget toplevel;
 Widget hostList,locationList,fileList;
 Widget searchText;
+Widget queryButton,abortButton;		/* global since changes sensitivity */
 
 static Widget statusText;
 static Widget hostText,locationText,fileText,sizeText,modesText,dateText;
@@ -88,12 +89,14 @@ AppResources appResources;
 static XtResource resources[] = {
     { "widgets", "Widgets", XtRString, sizeof(String),
       XtOffset(AppResources *,widgets), XtRImmediate, "" },
+    { "menus", "Menus", XtRString, sizeof(String),
+      XtOffset(AppResources *,menus), XtRImmediate, "" },
     { "searchType", "SearchType", GfRSearchType, sizeof(SearchType),
       XtOffset(AppResources *,searchType), XtRImmediate, (XtPointer)GfExact },
     { "sortType", "SortType", GfRSortType, sizeof(SortType),
       XtOffset(AppResources *,sortType), XtRImmediate, (XtPointer)GfDefault },
     { "archieHost", "ArchieHost", XtRString, sizeof(String),
-      XtOffset(AppResources *,archieHost), XtRImmediate, "archie.mcgill.ca" },
+      XtOffset(AppResources *,archieHost), XtRImmediate, "archie.sura.net" },
     { "maxHits", "MaxHits", XtRInt, sizeof(int),
       XtOffset(AppResources *,maxHits), XtRImmediate, (XtPointer)99 },
     { "offset", "Offset", XtRInt, sizeof(int),
@@ -112,6 +115,11 @@ static XtResource resources[] = {
       XtOffset(AppResources *,debugLevel), XtRImmediate, (XtPointer)0 },
     { "settingsWidgets", "SettingsWidgets", XtRString, sizeof(String),
       XtOffset(AppResources *,settingsWidgets), XtRImmediate, "" },
+    { "saveFormatOneLine", "SaveFormatOneLine", XtRBoolean, sizeof(Boolean),
+      XtOffset(AppResources *,saveFormatOneLine), XtRImmediate,
+							(XtPointer)False },
+    { "expert", "Expert", XtRBoolean, sizeof(Boolean),
+      XtOffset(AppResources *,expert), XtRImmediate, (XtPointer)False },
 };
 
 /*
@@ -129,13 +137,14 @@ static XrmOptionDescRec options[] = {
     { "-sort",    ".sortType",	 XrmoptionSepArg, (XtPointer)"default" },
     { "-t",	  ".sortType",	 XrmoptionNoArg,  (XtPointer)"invdate" },
     { "-host",	  ".archieHost", XrmoptionSepArg,
-					(XtPointer)"archie.mcgill.ca" },
+					(XtPointer)"archie.sura.net" },
     { "-maxhits", ".maxHits",	 XrmoptionSepArg, (XtPointer)"99" },
     { "-offset",  ".offset",	 XrmoptionSepArg, (XtPointer)"0" },
     { "-nice",    ".niceLevel",	 XrmoptionSepArg, (XtPointer)"0" },
     { "-N",       ".niceLevel",	 XrmoptionSepArg, (XtPointer)"0" },
-    { "-debug",	  ".debugLevel", XrmoptionNoArg,  (XtPointer)"1" },
+    { "-debug",	  ".debugLevel", XrmoptionSepArg, (XtPointer)"1" },
     { "-D",	  ".debugLevel", XrmoptionSepArg, (XtPointer)"1" },
+    { "-expert",  ".expert",     XrmoptionNoArg,  (XtPointer)"True" },
 };
 
 /*
@@ -156,7 +165,7 @@ main(argc,argv)
 int argc;
 char **argv;
 {
-    char buf[32];
+    char buf[64];
 
     progname = argv[0];
     initGraphics(&argc,argv);
@@ -165,13 +174,18 @@ char **argv;
 	XtDestroyApplicationContext(appContext);
 	exit(1);
     }
+    initErrorHandlers();
+    initSettingsDefaults();
     initWidgets();
     XtRealizeWidget(toplevel);
     /* Set window title to indicate version */
-    sprintf(buf,"xarchie %d.%d",xarchieMajorVersion,xarchieMinorVersion);
+    sprintf(buf,"xarchie %d.%d%s",xarchieMajorVersion,
+				  xarchieMinorVersion,
+				  xarchieExtraVersion);
     XStoreName(display,XtWindow(toplevel),buf);
-    sprintf(buf,"Welcome to xarchie %d.%d",xarchieMajorVersion,
-							xarchieMinorVersion);
+    sprintf(buf,"Welcome to xarchie %d.%d%s",xarchieMajorVersion,
+					     xarchieMinorVersion,
+					     xarchieExtraVersion);
     status0(buf);
     /* get the data structure for responses */
     db = newDb();
@@ -180,12 +194,8 @@ char **argv;
     /*NOTREACHED*/
 }
 
-void
-doPendingEvents()
-{
-    while (XtAppPending(appContext))
-	XtAppProcessEvent(appContext,XtIMAll);
-}
+/*	-	-	-	-	-	-	-	-	*/
+/* Initialization routines */
 
 static void
 initGraphics(argcp,argv)
@@ -230,6 +240,10 @@ initWidgets()
     sizeText = XtNameToWidget(toplevel,"*sizeText");
     modesText = XtNameToWidget(toplevel,"*modesText");
     dateText = XtNameToWidget(toplevel,"*dateText");
+    queryButton = XtNameToWidget(toplevel,"*queryButton");
+    abortButton = XtNameToWidget(toplevel,"*abortButton");
+    if (abortButton != NULL)
+	XtSetSensitive(abortButton,False);
     /* make the lists behave like a browser should */
     XtAddCallback(hostList,XtNcallback,selectItem,(XtPointer)1);
     XtAddCallback(locationList,XtNcallback,selectItem,(XtPointer)2);
@@ -238,6 +252,8 @@ initWidgets()
     clearList(hostList);
     clearList(locationList);
     clearList(fileList);
+    /* Some people crash when the EzMenu's are created earlier (puke-ola) */
+    initWidgetsFromString(appResources.menus,".menus");
 }
 
 #define ISSPACE(c)	((c) == ' ' || (c) == '\t' || (c) == '\n')
@@ -308,6 +324,53 @@ char *resourceStr,*resourceName;
 }
 
 /*	-	-	-	-	-	-	-	-	*/
+/* The following functions attempt to provide information in the event of
+ * a crash. If you have trouble compiling them because of UNIX-isms in
+ * the signal handlers, then add -DDONT_CATCH_ERRORS to the definition
+ * of DEFINES in the Imakefile and re-make (or just #define it here).
+ */
+#ifndef DONT_CATCH_ERRORS
+static void crashHandler();
+#endif /* DONT_CATCH_ERRORS */
+
+static void
+initErrorHandlers()
+{
+#ifndef DONT_CATCH_ERRORS
+    signal(SIGBUS,crashHandler);
+    signal(SIGSEGV,crashHandler);
+#endif /* DONT_CATCH_ERRORS */
+}
+
+#ifndef DONT_CATCH_ERRORS
+static void
+crashHandler(sig)
+int sig;
+{
+    char *s;
+
+    switch (sig) {
+	case SIGBUS: s = "SIGBUS"; break;
+	case SIGSEGV: s = "SIGSEGV"; break;
+	default: s = "UNKNOWN";
+    }
+    fprintf(stderr,"%s: caught a %s signal!\n",progname,s);
+    fprintf(stderr,"If a backtrace (using dbx or gdb or something) shows that the crash is\n");
+    fprintf(stderr,"is occurring in XtNameToWidget() or something similar, then before\n");
+    fprintf(stderr,"reporting an error, please check that your X distribution is up to date.\n");
+    fprintf(stderr,"Xarchie may not run under versions of X that are not at least X11R4\n");
+    fprintf(stderr,"with all fixes applied. Your copy of \".../include/X11/Intrinsic.h\"\n");
+    fprintf(stderr,"should have XConsortium revision number at least 1.139.\n");
+    fprintf(stderr,"If you still want to report an error, please indicate your hardware type,\n");
+    fprintf(stderr,"operating system, compiler, and your version of X and include a\n");
+    fprintf(stderr,"backtrace. Thanks.\n");
+    abort();
+}
+
+#endif /* DONT_CATCH_ERRORS */
+
+/*	-	-	-	-	-	-	-	-	*/
+
 /* Callback procedures */
 
 /*ARGSUSED*/
@@ -412,7 +475,7 @@ FileEntry *filep;
     }
     if (modesText != NULL)
 	setText(modesText,filep->modes);
-    if (sizeText != NULL)
+    if (dateText != NULL)
 	setText(dateText,filep->date);
 }
 
@@ -470,7 +533,6 @@ char *str;
 {
     if (statusText != NULL)
 	setText(statusText,str);
-    doPendingEvents();
 }
 
 void
